@@ -1,16 +1,19 @@
 # Tweepy
-# Copyright 2009-2021 Joshua Roesslein
+# Copyright 2009-2022 Joshua Roesslein
 # See LICENSE for details.
 
 """
 Tweepy Twitter API library
 """
-__version__ = '4.4.0'
+__version__ = '4.5.0'
 __author__ = 'Joshua Roesslein'
 __license__ = 'MIT'
 
 from tweepy.api import API
-from tweepy.auth import AppAuthHandler, OAuthHandler
+from tweepy.auth import (
+    AppAuthHandler, OAuthHandler, OAuth1UserHandler, OAuth2AppHandler,
+    OAuth2BearerHandler, OAuth2UserHandler
+)
 from tweepy.cache import Cache, FileCache, MemoryCache
 from tweepy.client import Client, Response
 from tweepy.cursor import Cursor
